==> comptechsoft-vue-foundation-1.0.6.tgz: package/src/~compvuetech/Classes/Axios/Axios.js <==
import Base from "../Base";

class Axios extends Base {

    constructor() {
        super();
       
        this.url = document.head.querySelector('meta[name="base-url"]').content
        
        this.endpoint = null
        this.data = null
        this.interval = 50
        this.timeout = null
        this.processing = false
        this.error = null
        this.success = null
        this.response = null

        this.onSuccess = () => {
            console.log('==== [Axios::onSuccess()] ====')
            console.log(this.response)
            console.log('============================')
        }
        this.onError = () => {
            console.log('==== [Axios::onError()] ====')
            console.log(this.error)
            console.log('============================')
        }
        
        axios.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest'
        axios.defaults.headers.common['X-CSRF-TOKEN'] = document.head.querySelector('meta[name="csrf-token"]').content
    }

    set endpoint(value) {
        this._endpoint = value
    }

    get endpoint() {
        if( ! this._endpoint)
        {
            return null
        }
        return ((this._endpoint.substr(0,4) === 'http') ? '' : this.url + '/') + this._endpoint
    }

    SetEndpoint(value) {
        this.endpoint = value
        return this
    }

    SetData(value) {
        this.data = value
        return this
    }

    OnSuccess(value) {
        this.onSuccess = value
        return this
    }

    OnError(value) {
        this.onError = value
        return this
    }

    Post() {
        if( this.timeout )
        {
            clearTimeout(this.timeout)
        }
        this.timeout = setTimeout(() => this.MakeRequest(), this.interval)
    }

    async MakeRequest() {
        console.log('Axios::MakeRequest(' + this.endpoint + ')')

        this.processing = true
        this.error = null
        this.success = null

        try
        {
            let requestResult = await axios.request({method: 'post', url: this.endpoint, data: this.data})
            this.success = true
            this.response = requestResult.data
            this.onSuccess()
        }
        catch(error)
        {
            this.success = false
            this.error = error
            this.onError()
        }

        this.processing = false
    }

}

export default Axios

==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Classes/Axios/Axios.js <==
import Base from "../Base";

class Axios extends Base {

    constructor() {
        super();
       
        this.url = document.head.querySelector('meta[name="base-url"]').content
        
        this.endpoint = null
        this.data = null
        this.interval = 200
        this.timeout = null
        this.processing = false
        this.error = null
        this.success = null
        this.response = null

        this.refresh_count = 0

        this.onSuccess = () => {
            // console.log('==== [Axios::onSuccess()] ====')
            // console.log(this.response)
            this.refresh_count++
            // console.log('============================')
        }
        this.onError = () => {
            console.log('==== [Axios::onError()] ====')
            console.log(this.error)
            console.log('============================')
        }
        
        
    }

    set endpoint(value) {
        this._endpoint = value
    }

    get endpoint() {
        if( ! this._endpoint)
        {
            return null
        }
        return ((this._endpoint.substr(0,4) === 'http') ? '' : this.url + '/') + this._endpoint
    }

    get refreshCount() {
        return this.refresh_count
    }

    SetEndpoint(value) {
        this.endpoint = value
        return this
    }

    SetData(value) {
        this.data = value
        return this
    }

    OnSuccess(value) {
        this.onSuccess = value
        return this
    }

    OnError(value) {
        this.onError = value
        return this
    }

    Post() {
        if( this.timeout )
        {
            clearTimeout(this.timeout)
        }

        this.timeout = setTimeout(() => this.MakeRequest(), this.interval)
    }

    ResetResponse() {
        this.response = null
        return this
    }

    MakeRequest() {
        let i = setInterval( () => {

            let reqWidth = axios.defaults.headers.common['X-Requested-With']
            let token = axios.defaults.headers.common['X-CSRF-TOKEN']
            let metaToken = document.head.querySelector('meta[name="csrf-token"]').content

            if( (reqWidth == 'XMLHttpRequest') && metaToken && (token == metaToken) )
            {
                clearInterval(i)
                this.mkReq() 
            }
            else
            {
                axios.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest'
                axios.defaults.headers.common['X-CSRF-TOKEN'] = document.head.querySelector('meta[name="csrf-token"]').content
            }
        }, 10)
    }

    async mkReq() {
        this.processing = true
        this.error = null
        this.success = null

        try
        {
            let requestResult = await axios.request({method: 'post', url: this.endpoint, data: this.data})
            this.success = true
            this.response = requestResult.data
            this.onSuccess()
        }
        catch(error)
        {
            this.success = false
            this.error = error
            this.onError()
        }

        this.processing = false
    }

}

export default Axios
